from setuptools import setup, find_packages

setup(
    name='hamidreza',
    version='0.1',
    description='A simple package with personal info about Hamidreza',
    author='Hamidreza',
    author_email='your-email@example.com',
    packages=find_packages(),
    install_requires=[],  # اگر پکیج‌های اضافی لازم دارید، اینجا اضافه کنید
)
